@@ -7,11 +7,6 @@ class Viper:
         self.name = name
         self.tests = []
         self.passed = 0
-
-    def clean(self):
-        for test in self.tests:
-            if type(test["desiredOutput"]) == list:
-                test["array"] = True
         
     def importFromFile(self, data):
         """
@@ -33,7 +28,18 @@ class Viper:
             "functionOutput" : function,
             "desiredOutput" : output
         })
-        self.clean()
+
+    def engine(self, test):
+        if type(test["desiredOutput"]) == list:
+            if test["functionOutput"] in test["desiredOutput"]:
+                return True
+            else:
+                return False
+        else:
+            if test["functionOutput"] == test["desiredOutput"]:
+                return True
+            else:
+                return False
 
     def evaluate(self):
         """ Evaluate all the tests """
@@ -45,21 +51,13 @@ class Viper:
             message = f"Testing \"{test['name']}\"... "
             print(message, end = "\r")
             time.sleep(0.75)
-            if test.get("array", False):
-                if test["functionOutput"] in test["desiredOutput"]:
-                    print(message + Fore.GREEN + "Passed" + Style.RESET_ALL)
-                    self.passed += 1
-                else:
-                    print(message + Fore.RED + "Failed" + Style.RESET_ALL)
-                    print(f"   Desired Output: {test['desiredOutput']} | Test Ouput: \"{test['functionOutput']}\"")
+            if self.engine(test):
+                print(message + Fore.GREEN + "Passed" + Style.RESET_ALL)
+                self.passed += 1
             else:
-                if test["functionOutput"] == test["desiredOutput"]:
-                    print(message + Fore.GREEN + "Passed" + Style.RESET_ALL)
-                    self.passed += 1
-                else:
-                    print(message + Fore.RED + "Failed" + Style.RESET_ALL)
-                    print(f"   Desired Output: \"{test['desiredOutput']}\" | Test Ouput: \"{test['functionOutput']}\"")
-        end = time.perf_counter() - (total * 0.75)
+                print(message + Fore.RED + "Failed" + Style.RESET_ALL)
+                print(f"   Desired Output: {test['desiredOutput']} | Test Ouput: \"{test['functionOutput']}\"")
+        end = time.perf_counter()
         time.sleep(0.75)
         print(f"\nRan {total} test(s) in {end - start:0.4f} seconds")
         print(f"{self.passed}/{total} passed")
\ No newline at end of file
